<?php

namespace Drupal\bootstrap_simple_carousel\Form;

use Drupal\bootstrap_simple_carousel\Service\CarouselService;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Class ItemsForm.
 *
 * Table item list form.
 *
 * @package Drupal\bootstrap_simple_carousel\Form
 */
class ItemsForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'bootstrap_simple_carousel_items_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $query = \Drupal::database()->select('bootstrap_simple_carousel', 'u');
    $query->fields('u');
    $items = $query->execute()->fetchAll();

    $header = [
      'cio' => $this->t('Item id'),
      'image_id' => $this->t('Image'),
      'caption_title' => $this->t('Caption title'),
      'caption_text' => $this->t('Caption text'),
      'status' => $this->t('Status'),
      'edit' => $this->t('Edit'),
      'delete' => $this->t('Delete'),
    ];

    $output = [];
    if (!empty($items)) {
      foreach ($items as $item) {
        $imageParams = [
          'alt' => $item->image_alt,
          'title' => $item->image_title,
        ];

        $output[$item->cid] = [
          'cio' => $item->cid,
          'image_id' => CarouselService::getInstance()
            ->renderImageById($item->image_id, 'thumbnail', $imageParams),
          'caption_title' => $item->caption_title,
          'caption_text' => $item->caption_text,
          'status' => CarouselService::getInstance()->getStatuses()[(bool) $item->status],
          'edit' => CarouselService::getInstance()->renderLink(
            Url::fromRoute('bootstrap_simple_carousel.edit', ['id' => $item->cid]),
            $this->t('edit')
          ),
          'delete' => CarouselService::getInstance()->renderLink(
            Url::fromRoute('bootstrap_simple_carousel.delete', ['id' => $item->cid]),
            $this->t('delete')
          ),
        ];
      }
    }

    $form['toolbar'] = [
      '#type' => 'fieldset',
      '#title' => '',
    ];
    $form['toolbar']['add_link'] = [
      '#title' => $this->t('Add element'),
      '#type' => 'link',
      '#url' => Url::fromRoute('bootstrap_simple_carousel.add'),
      '#attributes' => [
        'class' => ['button button-action button--primary button--small'],
      ],
    ];
    $form['toolbar']['settings_link'] = [
      '#title' => $this->t('Settings'),
      '#type' => 'link',
      '#url' => Url::fromRoute('bootstrap_simple_carousel.admin_settings'),
      '#attributes' => [
        'class' => ['button button--primary button--small'],
      ],
    ];

    $form['table'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $output,
      '#empty' => $this->t('No images found'),
    ];

    return $form;
  }

}
