<?php

namespace Drupal\bootstrap_simple_carousel\Plugin\Block;

use Drupal\bootstrap_simple_carousel\Form\SettingsForm;
use Drupal\Core\Annotation\Translation;
use Drupal\Core\Block\Annotation\Block;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Session\AccountInterface;
use Drupal\file\Entity\File;
use Drupal\image\Entity\ImageStyle;

/**
 * Provides a 'Bootstrap simple carousel' Block.
 *
 * @Block(
 *   id = "bootstrap_simple_carousel_block",
 *   admin_label = @Translation("Bootstrap simple carousel block")
 * )
 */
class CarouselBlock extends BlockBase {

  /** @var \Drupal\Core\Config\ImmutableConfig*/
  protected $moduleSettings;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->moduleSettings = \Drupal::config('bootstrap_simple_carousel.settings');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [
      '#items' => $this->getCarouselItems(),
      '#settings' => $this->moduleSettings,
      '#theme' => 'bootstrap_simple_carousel_block',
    ];

    if ($this->moduleSettings->get('assets')) {
      $build['#attached'] = [
        'library' => [
          'bootstrap_simple_carousel/bootstrap',
        ],
      ];
    }

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    return AccessResult::allowedIfHasPermission($account, 'access content');
  }

  /**
   * Returns an active carousel items.
   *
   * @return array|null
   *   Items list or null
   */
  protected function getCarouselItems() {
    $query = \Drupal::database()->select('bootstrap_simple_carousel', 'u');
    $query->fields('u');
    $query->condition('status', 1);
    $items = $query->execute()->fetchAll();

    if (!empty($items)) {
      foreach ($items as &$item) {
        $file = File::load($item->image_id);
        $image_style = $this->moduleSettings->get('image_style');
        if (empty($image_style) || $image_style == SettingsForm::ORIGINAL_IMAGE_STYLE_ID) {
          $item->image_url = file_create_url($file->getFileUri());
        }
        else {
          $item->image_url = ImageStyle::load($image_style)
            ->buildUrl($file->getFileUri());
        }
      }
    }

    return $items;
  }

}
